Module binary

Structs

Binary
Binary is a wrapper around Vec to add base64 de/serialization with serde. It also adds some helper methods to help encode inline.

Functions

from_json
Deserializes the given JSON bytes to a data structure.
to_json_binary
Serializes the given data structure as JSON bytes.
to_json_string
Serializes the given data structure as a JSON string.